@@ -55,7 +55,6 @@
 #' @importFrom dplyr case_when select
 #' @importFrom stats ftable
 #' @importFrom crayon cyan italic
-#' @importFrom cli cat_line
 #' @export
 flat_table <- function(data, ..., margin = c("counts", "cell", "row", "col"), digits = 2, show.values = FALSE) {
 
@@ -93,9 +92,9 @@ flat_table <- function(data, ..., margin = c("counts", "cell", "row", "col"), di
       tmp <- sjlabelled::copy_labels(grps$data[[i]], dd)
 
       # print title for grouping
-      cli::cat_line(crayon::cyan(crayon::italic(
+      cat(crayon::cyan(crayon::italic(
         sprintf("\nGrouped by:\n%s\n", get_grouped_title(dd, grps, i, sep = "\n"))
-      )))
+      )), "\n")
 
       # print frequencies
       print(com_ft(tmp, show.values, no.prop.table, marge, digits))
